@@ -1551,32 +1551,30 @@ get_start_tag (HTMLClueFlow *self)
 static const char *
 get_start_indent_item (HTMLListType type)
 {
-	if (type) {
-		switch (type) {
-		case HTML_LIST_TYPE_UNORDERED:
-		case HTML_LIST_TYPE_MENU:
-		case HTML_LIST_TYPE_DIR:
-			return "UL";
-		case HTML_LIST_TYPE_ORDERED_LOWER_ALPHA:
-			return "OL TYPE=a";
-		case HTML_LIST_TYPE_ORDERED_UPPER_ALPHA:
-			return "OL TYPE=A";
-		case HTML_LIST_TYPE_ORDERED_LOWER_ROMAN:
-			return "OL TYPE=i";
-		case HTML_LIST_TYPE_ORDERED_UPPER_ROMAN:
-		return "OL TYPE=I";
-		case HTML_LIST_TYPE_ORDERED_ARABIC:
-			return "OL TYPE=1";
-		case HTML_LIST_TYPE_GLOSSARY_DD:
-		case HTML_LIST_TYPE_GLOSSARY_DL:
-			return "DL";
-		case HTML_LIST_TYPE_BLOCKQUOTE_CITE:
-			return "BLOCKQUOTE TYPE=CITE";
-		case HTML_LIST_TYPE_BLOCKQUOTE:
-			return "BLOCKQUOTE";
-		}
-	} else 
-		return "";
+	switch (type) {
+	case HTML_LIST_TYPE_UNORDERED:
+	case HTML_LIST_TYPE_MENU:
+	case HTML_LIST_TYPE_DIR:
+		return "UL";
+	case HTML_LIST_TYPE_ORDERED_LOWER_ALPHA:
+		return "OL TYPE=a";
+	case HTML_LIST_TYPE_ORDERED_UPPER_ALPHA:
+		return "OL TYPE=A";
+	case HTML_LIST_TYPE_ORDERED_LOWER_ROMAN:
+		return "OL TYPE=i";
+	case HTML_LIST_TYPE_ORDERED_UPPER_ROMAN:
+	return "OL TYPE=I";
+	case HTML_LIST_TYPE_ORDERED_ARABIC:
+		return "OL TYPE=1";
+	case HTML_LIST_TYPE_GLOSSARY_DD:
+	case HTML_LIST_TYPE_GLOSSARY_DL:
+		return "DL";
+	case HTML_LIST_TYPE_BLOCKQUOTE_CITE:
+		return "BLOCKQUOTE TYPE=CITE";
+	case HTML_LIST_TYPE_BLOCKQUOTE:
+		return "BLOCKQUOTE";
+	}
+	return "";
 }
 
 static const char *
@@ -2475,8 +2473,8 @@ html_clueflow_real_get_direction (HTMLObject *o)
 		HTMLObject *child;
 		for (child = HTML_CLUE (o)->head; child; child = child->next) {
 			if (HTML_IS_TEXT (child)) {
-				if (child == HTML_CLUE (o)->head && html_object_get_length (child) == 0 && o->prev)
-					return html_object_get_direction (o->prev);
+				/*if (child == HTML_CLUE (o)->head && html_object_get_length (child) == 0 && o->prev)
+					return html_object_get_direction (o->prev);*/
 
 				dir = html_text_direction_pango_to_html (html_text_get_pango_direction (HTML_TEXT (child)));
 
